#ifndef STRID_H_
#define STRID_H_

/*
 * strid is a library to convert strings to integers, where two equal strings
 * are guaranteed to get the same id, but different stirngs should get differnet
 * ids
 *
 * The library is designed to convert event names or similar to id:s. The id
 * sequence starts from 0 and increases.
 *
 * The strid contains a map of all strings in memory, so don't use it for user
 * input data if the strid instance is kept alive for long.
 */

struct strid_t;

/**
 * Create a storage for name<->id mappings
 */
struct strid_t *strid_create(void);

/**
 * Destroy the storage
 */
void strid_destroy(struct strid_t *si);

/**
 * Get the id for a given name. This takes the time of O(log(N)), N=number of
 * keys
 */
int strid_get(struct strid_t *si, const char *str);

#endif
